@@ -13,7 +13,7 @@ STATE_APP_RUNNING      = "Running"
 STATE_APP_STOPPING     = "Stopping"
 STATE_APP_STOPPED      = "Stopped"
 STATE_APP_STARTING     = "Starting"
-STATE_APP_REBOOTING    = "Rebooting"
+STATE_APP_RESTARTING   = "Restarting"
 #STATE_APP_CLONING      = "Cloning"
 STATE_APP_TERMINATING  = "Terminating"
 STATE_APP_TERMINATED   = "Terminated"
