@@ -7,6 +7,7 @@ note: Part of these functions have been extracted and/or modified
       from the Salt (SaltStack) Docker module
 '''
 
+import time
 import json
 import os
 import docker
@@ -124,6 +125,10 @@ def _get_image_infos(config,image):
         pass
     return infos
 
+# external access
+def get_container_infos(config,container):
+    return _get_container_infos(config, container)
+
 def _get_container_infos(config, container):
     '''
     Get container infos
@@ -682,7 +687,7 @@ def installed(config,
               dns=None,
               volumes=None,
               volumes_from=None,
-              force=False,
+              force=True,
               *args, **kwargs):
     '''
     Ensure that a container with the given name exists;
@@ -739,9 +744,13 @@ def installed(config,
         utils.error("Image not found.")
         return None
     cinfos = _get_container_infos(config, name)
-    if cinfos:
+    force = (config["force"] if config.get("force") != None else force)
+    if cinfos and force:
         remove_container(config, container=name,force=True)
         print "Old container removed."
+    elif cinfos and (not force):
+        print "Container found: %s."%cinfos.get("Id")
+        return cinfos
 
     dports, dvolumes, denvironment, de = {}, [], {}, {}
     if not ports:
@@ -816,7 +825,7 @@ def running(config,
             publish_all_ports=False,
             links=None,
             port_bindings=None,
-            force=False,
+            force=True,
             hostname=None,
             *args, **kwargs):
     '''
@@ -1177,6 +1186,7 @@ _deploy = {
             'cpu_shares'    : 'cpu_shares',
             'ports'         : 'ports',
             'hostname'      : 'hostname',
+            'force'         : 'force',
             # running
 #            'publish_all_ports': 'publish_all_ports',
             'binds'         : 'binds',
